Crate kcr_charts_operatorhub_io

Crate kcr_charts_operatorhub_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the charts.operatorhub.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

charts.operatorhub.io/v1alpha1

  • Cockroachdb

Modules

v1alpha1